@@ -36,7 +36,7 @@ sub do_config_REGEXP {
     print STDERR "...\n";
     print STDERR "... regexp_engine structure configuration\n";
     print STDERR "...\n";
-    foreach (qw/comp exec intuit checkstr free numbered_buff_FETCH numbered_buff_STORE numbered_buff_LENGTH named_buff named_buff_iter qr_package dupe op_comp/) {
+    foreach (qw/comp exec intuit checkstr free rxfree numbered_buff_FETCH numbered_buff_STORE numbered_buff_LENGTH named_buff named_buff_iter qr_package dupe op_comp/) {
         $ac->check_member("regexp_engine.$_", { prologue => "#include \"EXTERN.h\"
 #include \"perl.h\"
 #include \"XSUB.h\"
